pub fn compute_return_value_for_stubbed_function(
    project: &Project,
    state: &mut State,
    extern_symbol: &ExternSymbol,
    call_tid: &Tid
) -> DataDomain<BitvectorDomain>
Compute the return value of a call to a known extern symbol from the given state.

Note that this function needs to be called before non-callee-saved registers are cleared from the state, since the return value is usually computed out of the parameter values.

This function should only be called for symbols contained in the list returned by generate_param_access_stubs, since it assumes untracked return values (e.g. integers or void) for all not explicitly handled symbols.